@@ -1,5 +1,5 @@
 package Terse;
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 use 5.006;
 use strict;
 use warnings;
@@ -129,10 +129,6 @@ sub _response {
 	my $res = $self->request->new_response($response_body->status_code ||= $status ||= 200);
 	$res->cookies->{sid} = $cookie if $cookie;
 	$res->content_type('application/json');
-	for (qw/error authenticated/) {
-		$response_body->$_ = $response_body->$_ ? \1 : \0 
-			if exists $response_body->{$_};
-	}
 	$res->body($response_body->serialize());
 	return $res->finalize;
 }
@@ -258,8 +254,8 @@ sub AUTOLOAD : lvalue {
 	my $miss = Want::want('REF OBJECT') ? {} : '';
 	my $retval = $_[0]->{$key};
 	return $retval->(@_) if (ref $retval eq 'CODE');
-	#my $isBool = Want::want('SCALAR BOOL') && ((reftype($retval) // '') eq 'SCALAR');
-	#$retval = $$retval if $isBool;
+	my $isBool = Want::want('SCALAR BOOL') && ((reftype($retval) // '') eq 'SCALAR');
+	return $$retval if $isBool;
 	$_[0]->{$key} = $_[1] // $retval // $miss;
 	$_[0]->_bless_tree($_[0]->{$key}) if ref $_[0]->{$key} eq 'HASH' || ref $_[0]->{$key} eq 'ARRAY';
 	$_[0]->{$key};
@@ -275,7 +271,7 @@ Terse - lightweight JSON APIs.
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =cut
 
